/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from "react";
import { Checkbox, Icon, Label, Table } from "semantic-ui-react";
/**
 * Transfer list item component.
 *
 * @param {TransferListItemPropsInterface} props - Props injected to the component.
 * @return {React.ReactElement}
 */
export const TransferListItem = (props) => {
    const { listItem, listItemId, listItemIndex, listItemTypeLabel, isItemChecked, handleItemChange, handleItemClick, showSecondaryActions } = props;
    return (React.createElement(Table.Row, null,
        React.createElement(Table.Cell, { id: listItemId, key: listItemIndex, width: 2 },
            React.createElement(Checkbox, { checked: isItemChecked, onChange: handleItemChange, onClick: handleItemClick })),
        React.createElement(Table.Cell, { id: listItemId, key: listItemIndex, width: 4 }, listItem),
        listItemTypeLabel && (React.createElement(Table.Cell, { key: listItemIndex },
            React.createElement(Label, { color: listItemTypeLabel.labelColor, content: listItemTypeLabel.labelText, size: "mini", className: listItemTypeLabel.name }))),
        showSecondaryActions && (React.createElement(Table.Cell, { key: listItemIndex, width: 2 },
            React.createElement(Icon, { color: "grey", name: "ellipsis vertical" })))));
};
//# sourceMappingURL=transfer-list-item.js.map